"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Camera = void 0;
const log_1 = require("../log");
const serialport_1 = require("serialport");
const parser_readline_1 = require("@serialport/parser-readline");
class Camera {
    constructor() {
        this.ready = false;
        this.serial = null;
        this.baud = 57600;
        this.log = (0, log_1.createLog)('camera');
        this.parser = new parser_readline_1.ReadlineParser({ delimiter: '\r\n' });
        this.begin();
    }
    async begin() {
        let ports = [];
        let selected = false;
        try {
            ports = await this.enumerate();
        }
        catch (err) {
            this.log.error('Error calling enumerate()', err);
        }
        if (ports.length === 0) {
            this.log.warn('No USB camera devices connected');
            return;
        }
        for (let port of ports) {
            this.log.info(`Found USB serial device: ${port} ${selected ? '*' : ''}`);
            selected = false;
        }
        try {
            await this.connect(ports[0]);
        }
        catch (err) {
            this.log.error(`Error connecting to ${ports[0]}`, err);
        }
    }
    filter(port) {
        if ((port.manufacturer + '').toLowerCase().indexOf('arduino') !== -1 ||
            (port.path + '').toLowerCase().indexOf('usbserial') !== -1 ||
            (port.path + '').toLowerCase().indexOf('usbmodem') !== -1 ||
            (port.path + '').toLowerCase().indexOf('ttyusb') !== -1) {
            return true;
        }
        return false;
    }
    async enumerate() {
        let listed = [];
        try {
            listed = await serialport_1.SerialPort.list();
        }
        catch (err) {
            this.log.error('Error listing serial ports', err);
        }
        return listed.filter(this.filter).map((port) => port.path);
    }
    async connect(port) {
        try {
            this.serial = new serialport_1.SerialPort({
                path: port,
                autoOpen: false,
                baudRate: this.baud,
            });
        }
        catch (err) {
            this.log.error('Error creating SerialPort object', err);
        }
        if (this.serial !== null) {
            this.serial.pipe(this.parser);
            this.parser.on('data', this.onData.bind(this));
        }
        this.ready = true;
    }
    onData(data) {
        this.log.info(`Data received: "${data}"`);
    }
}
exports.Camera = Camera;
module.exports = { Camera };
//# sourceMappingURL=index.js.map